diff --git a/src/regionModels/Allwclean b/src/regionModels/Allwclean
index def3e82f78c4a4f0aff29439b32bd8a3b239b4b8..f95d816a531fc1f4a94727559b5cf7303cee193f 100755
--- a/src/regionModels/Allwclean
+++ b/src/regionModels/Allwclean
@@ -6,7 +6,7 @@ set -x
 wclean $makeType regionModel
 wclean $makeType pyrolysisModels
 wclean $makeType surfaceFilmModels
-wclean $makeType thermoBaffleModels
+wclean $makeType thermalBaffleModels
 wclean $makeType regionCoupling
 
 
diff --git a/src/regionModels/Allwmake b/src/regionModels/Allwmake
index 5c97cae02b1c15bd910e3547f6c7ae639b82d25e..0ca6e6338a93971b6d30465386179a1f088386e2 100755
--- a/src/regionModels/Allwmake
+++ b/src/regionModels/Allwmake
@@ -6,7 +6,7 @@ set -x
 wmake $makeType regionModel
 wmake $makeType pyrolysisModels
 wmake $makeType surfaceFilmModels
-wmake $makeType thermoBaffleModels
+wmake $makeType thermalBaffleModels
 wmake $makeType regionCoupling
 
 
diff --git a/src/regionModels/regionModel/derivedFvPatches/mappedVariableThicknessWall/mappedVariableThicknessWallFvPatch.C b/src/regionModels/regionModel/derivedFvPatches/mappedVariableThicknessWall/mappedVariableThicknessWallFvPatch.C
index 74a4416e2d35bbf7bd7e59871e93b704bfc01731..18b73623298d5d95a66a1d635efa9baa6ab231a0 100644
--- a/src/regionModels/regionModel/derivedFvPatches/mappedVariableThicknessWall/mappedVariableThicknessWallFvPatch.C
+++ b/src/regionModels/regionModel/derivedFvPatches/mappedVariableThicknessWall/mappedVariableThicknessWallFvPatch.C
@@ -54,7 +54,7 @@ makeDeltaCoeffs(scalarField& dc) const
     const modelType& region1D =
         patch().boundaryMesh().mesh().time().lookupObject<modelType>
         (
-            "thermoBaffleProperties"
+            "thermalBaffleProperties"
         );
 
     dc = 2.0/(pp.thickness()/region1D.nLayers());
diff --git a/src/regionModels/thermalBaffleModels/Make/files b/src/regionModels/thermalBaffleModels/Make/files
new file mode 100644
index 0000000000000000000000000000000000000000..dd0a6ebada305ee6d374dbbf8c08ec58e7d4d30c
--- /dev/null
+++ b/src/regionModels/thermalBaffleModels/Make/files
@@ -0,0 +1,9 @@
+thermalBaffleModel/thermalBaffleModel.C
+thermalBaffleModel/thermalBaffleModelNew.C
+thermalBaffle/thermalBaffle.C
+noThermo/noThermo.C
+
+derivedFvPatchFields/thermalBaffle/thermalBaffleFvPatchScalarField.C
+
+
+LIB = $(FOAM_LIBBIN)/libthermalBaffleModels
diff --git a/src/regionModels/thermoBaffleModels/Make/options b/src/regionModels/thermalBaffleModels/Make/options
similarity index 100%
rename from src/regionModels/thermoBaffleModels/Make/options
rename to src/regionModels/thermalBaffleModels/Make/options
diff --git a/src/regionModels/thermoBaffleModels/derivedFvPatchFields/doc/thermoBaffleBoundaryConditionsDoc.H b/src/regionModels/thermalBaffleModels/derivedFvPatchFields/doc/thermalBaffleBoundaryConditionsDoc.H
similarity index 100%
rename from src/regionModels/thermoBaffleModels/derivedFvPatchFields/doc/thermoBaffleBoundaryConditionsDoc.H
rename to src/regionModels/thermalBaffleModels/derivedFvPatchFields/doc/thermalBaffleBoundaryConditionsDoc.H
diff --git a/src/regionModels/thermoBaffleModels/derivedFvPatchFields/thermoBaffle/thermoBaffleFvPatchScalarField.C b/src/regionModels/thermalBaffleModels/derivedFvPatchFields/thermalBaffle/thermalBaffleFvPatchScalarField.C
similarity index 85%
rename from src/regionModels/thermoBaffleModels/derivedFvPatchFields/thermoBaffle/thermoBaffleFvPatchScalarField.C
rename to src/regionModels/thermalBaffleModels/derivedFvPatchFields/thermalBaffle/thermalBaffleFvPatchScalarField.C
index 471295924eb18851af009eac6e06e15685a64b9f..408076b482169fbd7318ee928b2ce8d59d750486 100644
--- a/src/regionModels/thermoBaffleModels/derivedFvPatchFields/thermoBaffle/thermoBaffleFvPatchScalarField.C
+++ b/src/regionModels/thermalBaffleModels/derivedFvPatchFields/thermalBaffle/thermalBaffleFvPatchScalarField.C
@@ -23,7 +23,7 @@ License
 
 \*---------------------------------------------------------------------------*/
 
-#include "thermoBaffleFvPatchScalarField.H"
+#include "thermalBaffleFvPatchScalarField.H"
 #include "addToRunTimeSelectionTable.H"
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
@@ -35,8 +35,8 @@ namespace compressible
 
 // * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //
 
-thermoBaffleFvPatchScalarField::
-thermoBaffleFvPatchScalarField
+thermalBaffleFvPatchScalarField::
+thermalBaffleFvPatchScalarField
 (
     const fvPatch& p,
     const DimensionedField<scalar, volMesh>& iF
@@ -49,10 +49,10 @@ thermoBaffleFvPatchScalarField
 {}
 
 
-thermoBaffleFvPatchScalarField::
-thermoBaffleFvPatchScalarField
+thermalBaffleFvPatchScalarField::
+thermalBaffleFvPatchScalarField
 (
-    const thermoBaffleFvPatchScalarField& ptf,
+    const thermalBaffleFvPatchScalarField& ptf,
     const fvPatch& p,
     const DimensionedField<scalar, volMesh>& iF,
     const fvPatchFieldMapper& mapper
@@ -71,8 +71,8 @@ thermoBaffleFvPatchScalarField
 {}
 
 
-thermoBaffleFvPatchScalarField::
-thermoBaffleFvPatchScalarField
+thermalBaffleFvPatchScalarField::
+thermalBaffleFvPatchScalarField
 (
     const fvPatch& p,
     const DimensionedField<scalar, volMesh>& iF,
@@ -88,8 +88,8 @@ thermoBaffleFvPatchScalarField
     {
         FatalErrorIn
         (
-            "thermoBaffleFvPatchScalarField::"
-            "thermoBaffleFvPatchScalarField\n"
+            "thermalBaffleFvPatchScalarField::"
+            "thermalBaffleFvPatchScalarField\n"
             "(\n"
             "    const fvPatch& p,\n"
             "    const DimensionedField<scalar, volMesh>& iF,\n"
@@ -110,7 +110,7 @@ thermoBaffleFvPatchScalarField
 
     const fvMesh& thisMesh = patch().boundaryMesh().mesh();
 
-    typedef regionModels::thermoBaffleModels::thermoBaffleModel baffle;
+    typedef regionModels::thermalBaffleModels::thermalBaffleModel baffle;
 
     if
     (
@@ -127,10 +127,10 @@ thermoBaffleFvPatchScalarField
 }
 
 
-thermoBaffleFvPatchScalarField::
-thermoBaffleFvPatchScalarField
+thermalBaffleFvPatchScalarField::
+thermalBaffleFvPatchScalarField
 (
-    const thermoBaffleFvPatchScalarField& ptf,
+    const thermalBaffleFvPatchScalarField& ptf,
     const DimensionedField<scalar, volMesh>& iF
 )
 :
@@ -144,7 +144,7 @@ thermoBaffleFvPatchScalarField
 // * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //
 
 
-void thermoBaffleFvPatchScalarField::autoMap
+void thermalBaffleFvPatchScalarField::autoMap
 (
     const fvPatchFieldMapper& m
 )
@@ -153,7 +153,7 @@ void thermoBaffleFvPatchScalarField::autoMap
 }
 
 
-void thermoBaffleFvPatchScalarField::rmap
+void thermalBaffleFvPatchScalarField::rmap
 (
     const fvPatchScalarField& ptf,
     const labelList& addr
@@ -163,7 +163,7 @@ void thermoBaffleFvPatchScalarField::rmap
 }
 
 
-void thermoBaffleFvPatchScalarField::updateCoeffs()
+void thermalBaffleFvPatchScalarField::updateCoeffs()
 {
     if (this->updated())
     {
@@ -181,7 +181,7 @@ void thermoBaffleFvPatchScalarField::updateCoeffs()
 }
 
 
-void thermoBaffleFvPatchScalarField::write(Ostream& os) const
+void thermalBaffleFvPatchScalarField::write(Ostream& os) const
 {
     turbulentTemperatureCoupledBaffleMixedFvPatchScalarField::write(os);
 
@@ -189,9 +189,9 @@ void thermoBaffleFvPatchScalarField::write(Ostream& os) const
 
     if (thisMesh.name() == polyMesh::defaultRegion && owner_)
     {
-        word thermoModel = dict_.lookup("thermoBaffleModel");
+        word thermoModel = dict_.lookup("thermalBaffleModel");
 
-        os.writeKeyword("thermoBaffleModel")
+        os.writeKeyword("thermalBaffleModel")
             << thermoModel
             << token::END_STATEMENT << nl;
 
@@ -227,7 +227,7 @@ void thermoBaffleFvPatchScalarField::write(Ostream& os) const
 makePatchTypeField
 (
     fvPatchScalarField,
-    thermoBaffleFvPatchScalarField
+    thermalBaffleFvPatchScalarField
 );
 
 
diff --git a/src/regionModels/thermoBaffleModels/Make/files b/src/regionModels/thermoBaffleModels/Make/files
deleted file mode 100644
index 2799f6460bebca2c19b0e967648f10a6f5985396..0000000000000000000000000000000000000000
--- a/src/regionModels/thermoBaffleModels/Make/files
+++ /dev/null
@@ -1,9 +0,0 @@
-thermoBaffleModel/thermoBaffleModel.C
-thermoBaffleModel/thermoBaffleModelNew.C
-thermoBaffle/thermoBaffle.C
-noThermo/noThermo.C
-
-derivedFvPatchFields/thermoBaffle/thermoBaffleFvPatchScalarField.C
-
-
-LIB = $(FOAM_LIBBIN)/libthermoBaffleModels
diff --git a/src/turbulenceModels/compressible/turbulenceModel/Make/files b/src/turbulenceModels/compressible/turbulenceModel/Make/files
index e089735210054addf0e20ed8016f93eb256c6d8c..5bb1f79ba925f65de57a2c23a537394109b9c4f8 100644
--- a/src/turbulenceModels/compressible/turbulenceModel/Make/files
+++ b/src/turbulenceModels/compressible/turbulenceModel/Make/files
@@ -4,10 +4,10 @@ laminar/laminar.C
 derivedFvPatchFields/turbulentHeatFluxTemperature/turbulentHeatFluxTemperatureFvPatchScalarField.C
 derivedFvPatchFields/temperatureCoupledBase/temperatureCoupledBase.C
 derivedFvPatchFields/turbulentTemperatureCoupledBaffleMixed/turbulentTemperatureCoupledBaffleMixedFvPatchScalarField.C
-derivedFvPatchFields/thermoBaffle1D/thermoBaffle1DFvPatchScalarFields.C
+derivedFvPatchFields/thermalBaffle1D/thermalBaffle1DFvPatchScalarFields.C
 derivedFvPatchFields/totalFlowRateAdvectiveDiffusive/totalFlowRateAdvectiveDiffusiveFvPatchScalarField.C
 derivedFvPatchFields/turbulentTemperatureRadCoupledMixed/turbulentTemperatureRadCoupledMixedFvPatchScalarField.C
 derivedFvPatchFields/externalWallHeatFluxTemperature/externalWallHeatFluxTemperatureFvPatchScalarField.C
-
+derivedFvPatchFields/wallHeatTransfer/wallHeatTransferFvPatchScalarField.C
 
 LIB = $(FOAM_LIBBIN)/libcompressibleTurbulenceModel
diff --git a/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermoBaffle1D/thermoBaffle1DFvPatchScalarField.C b/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermalBaffle1D/thermalBaffle1DFvPatchScalarField.C
similarity index 90%
rename from src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermoBaffle1D/thermoBaffle1DFvPatchScalarField.C
rename to src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermalBaffle1D/thermalBaffle1DFvPatchScalarField.C
index 2d4f331e20200e85dd442001d659367956c505c7..1ccc6f7fa3daf58f8d3ba69821f45e6ade87c14a 100644
--- a/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermoBaffle1D/thermoBaffle1DFvPatchScalarField.C
+++ b/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermalBaffle1D/thermalBaffle1DFvPatchScalarField.C
@@ -39,8 +39,8 @@ namespace compressible
 // * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //
 
 template<class solidType>
-thermoBaffle1DFvPatchScalarField<solidType>::
-thermoBaffle1DFvPatchScalarField
+thermalBaffle1DFvPatchScalarField<solidType>::
+thermalBaffle1DFvPatchScalarField
 (
     const fvPatch& p,
     const DimensionedField<scalar, volMesh>& iF
@@ -56,10 +56,10 @@ thermoBaffle1DFvPatchScalarField
 
 
 template<class solidType>
-thermoBaffle1DFvPatchScalarField<solidType>::
-thermoBaffle1DFvPatchScalarField
+thermalBaffle1DFvPatchScalarField<solidType>::
+thermalBaffle1DFvPatchScalarField
 (
-    const thermoBaffle1DFvPatchScalarField& ptf,
+    const thermalBaffle1DFvPatchScalarField& ptf,
     const fvPatch& p,
     const DimensionedField<scalar, volMesh>& iF,
     const fvPatchFieldMapper& mapper
@@ -75,8 +75,8 @@ thermoBaffle1DFvPatchScalarField
 
 
 template<class solidType>
-thermoBaffle1DFvPatchScalarField<solidType>::
-thermoBaffle1DFvPatchScalarField
+thermalBaffle1DFvPatchScalarField<solidType>::
+thermalBaffle1DFvPatchScalarField
 (
     const fvPatch& p,
     const DimensionedField<scalar, volMesh>& iF,
@@ -94,8 +94,8 @@ thermoBaffle1DFvPatchScalarField
     {
         FatalErrorIn
         (
-            "thermoBaffle1DFvPatchScalarField::"
-            "thermoBaffle1DFvPatchScalarField"
+            "thermalBaffle1DFvPatchScalarField::"
+            "thermalBaffle1DFvPatchScalarField"
             "("
                 "const fvPatch&,\n"
                 "const DimensionedField<scalar, volMesh>&, "
@@ -130,10 +130,10 @@ thermoBaffle1DFvPatchScalarField
 
 
 template<class solidType>
-thermoBaffle1DFvPatchScalarField<solidType>::
-thermoBaffle1DFvPatchScalarField
+thermalBaffle1DFvPatchScalarField<solidType>::
+thermalBaffle1DFvPatchScalarField
 (
-    const thermoBaffle1DFvPatchScalarField& ptf
+    const thermalBaffle1DFvPatchScalarField& ptf
 )
 :
     mixedFvPatchScalarField(ptf),
@@ -146,10 +146,10 @@ thermoBaffle1DFvPatchScalarField
 
 
 template<class solidType>
-thermoBaffle1DFvPatchScalarField<solidType>::
-thermoBaffle1DFvPatchScalarField
+thermalBaffle1DFvPatchScalarField<solidType>::
+thermalBaffle1DFvPatchScalarField
 (
-    const thermoBaffle1DFvPatchScalarField& ptf,
+    const thermalBaffle1DFvPatchScalarField& ptf,
     const DimensionedField<scalar, volMesh>& iF
 )
 :
@@ -165,7 +165,7 @@ thermoBaffle1DFvPatchScalarField
 // * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //
 
 template<class solidType>
-void thermoBaffle1DFvPatchScalarField<solidType>::autoMap
+void thermalBaffle1DFvPatchScalarField<solidType>::autoMap
 (
     const fvPatchFieldMapper& m
 )
@@ -174,7 +174,7 @@ void thermoBaffle1DFvPatchScalarField<solidType>::autoMap
 }
 
 template<class solidType>
-void thermoBaffle1DFvPatchScalarField<solidType>::rmap
+void thermalBaffle1DFvPatchScalarField<solidType>::rmap
 (
     const fvPatchScalarField& ptf,
     const labelList& addr
@@ -185,7 +185,7 @@ void thermoBaffle1DFvPatchScalarField<solidType>::rmap
 
 
 template<class solidType>
-void thermoBaffle1DFvPatchScalarField<solidType>::updateCoeffs()
+void thermalBaffle1DFvPatchScalarField<solidType>::updateCoeffs()
 {
     if (updated())
     {
@@ -242,8 +242,8 @@ void thermoBaffle1DFvPatchScalarField<solidType>::updateCoeffs()
         );
         mpp.map().distribute(nbrQDot);
 
-        const thermoBaffle1DFvPatchScalarField& nbrField =
-        refCast<const thermoBaffle1DFvPatchScalarField>
+        const thermalBaffle1DFvPatchScalarField& nbrField =
+        refCast<const thermalBaffle1DFvPatchScalarField>
         (
             nbrPatch.template lookupPatchField<volScalarField, scalar>(TName_)
         );
@@ -347,7 +347,7 @@ void thermoBaffle1DFvPatchScalarField<solidType>::updateCoeffs()
 }
 
 template <class solidType>
-void thermoBaffle1DFvPatchScalarField<solidType>::
+void thermalBaffle1DFvPatchScalarField<solidType>::
 write(Ostream& os) const
 {
     mixedFvPatchScalarField::write(os);
diff --git a/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermoBaffle1D/thermoBaffle1DFvPatchScalarFields.C b/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermalBaffle1D/thermalBaffle1DFvPatchScalarFields.C
similarity index 83%
rename from src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermoBaffle1D/thermoBaffle1DFvPatchScalarFields.C
rename to src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermalBaffle1D/thermalBaffle1DFvPatchScalarFields.C
index 2e180238f49c2ef735362b42ea90ce1bfb1c196c..979980cff5525a55d907b83f29c4c7535b609163 100644
--- a/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermoBaffle1D/thermoBaffle1DFvPatchScalarFields.C
+++ b/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermalBaffle1D/thermalBaffle1DFvPatchScalarFields.C
@@ -23,7 +23,7 @@ License
 
 \*---------------------------------------------------------------------------*/
 
-#include "thermoBaffle1DFvPatchScalarFields.H"
+#include "thermalBaffle1DFvPatchScalarFields.H"
 #include "addToRunTimeSelectionTable.H"
 
 
@@ -38,28 +38,28 @@ namespace compressible
 
 defineTemplateTypeNameAndDebugWithName
 (
-    constSolid_thermoBaffle1DFvPatchScalarField,
-    "compressible::thermoBaffle1D<hConstSolidThermoPhysics>",
+    constSolid_thermalBaffle1DFvPatchScalarField,
+    "compressible::thermalBaffle1D<hConstSolidThermoPhysics>",
     0
 );
 
 addToPatchFieldRunTimeSelection
 (
     fvPatchScalarField,
-    constSolid_thermoBaffle1DFvPatchScalarField
+    constSolid_thermalBaffle1DFvPatchScalarField
 );
 
 defineTemplateTypeNameAndDebugWithName
 (
-    expoSolid_thermoBaffle1DFvPatchScalarField,
-    "compressible::thermoBaffle1D<hExponentialSolidThermoPhysics>",
+    expoSolid_thermalBaffle1DFvPatchScalarField,
+    "compressible::thermalBaffle1D<hExponentialSolidThermoPhysics>",
     0
 );
 
 addToPatchFieldRunTimeSelection
 (
     fvPatchScalarField,
-    expoSolid_thermoBaffle1DFvPatchScalarField
+    expoSolid_thermalBaffle1DFvPatchScalarField
 );
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
diff --git a/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermoBaffle1D/thermoBaffle1DFvPatchScalarFields.H b/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermalBaffle1D/thermalBaffle1DFvPatchScalarFields.H
similarity index 84%
rename from src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermoBaffle1D/thermoBaffle1DFvPatchScalarFields.H
rename to src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermalBaffle1D/thermalBaffle1DFvPatchScalarFields.H
index 931aeaae0705ce1896bcc0e0224a4facdb618300..14f88a25c6c996f8131c2832897685a1ddb9e492 100644
--- a/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermoBaffle1D/thermoBaffle1DFvPatchScalarFields.H
+++ b/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermalBaffle1D/thermalBaffle1DFvPatchScalarFields.H
@@ -23,10 +23,10 @@ License
 
 \*---------------------------------------------------------------------------*/
 
-#ifndef thermoBaffle1DFvPatchScalarFields_H
-#define thermoBaffle1DFvPatchScalarFields_H
+#ifndef thermalBaffle1DFvPatchScalarFields_H
+#define thermalBaffle1DFvPatchScalarFields_H
 
-#include "thermoBaffle1DFvPatchScalarField.H"
+#include "thermalBaffle1DFvPatchScalarField.H"
 #include "solidThermoPhysicsTypes.H"
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
@@ -38,15 +38,15 @@ namespace compressible
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
-    typedef thermoBaffle1DFvPatchScalarField
+    typedef thermalBaffle1DFvPatchScalarField
     <
         hConstSolidThermoPhysics
-    >constSolid_thermoBaffle1DFvPatchScalarField;
+    >constSolid_thermalBaffle1DFvPatchScalarField;
 
-    typedef thermoBaffle1DFvPatchScalarField
+    typedef thermalBaffle1DFvPatchScalarField
     <
         hExponentialSolidThermoPhysics
-    >expoSolid_thermoBaffle1DFvPatchScalarField;
+    >expoSolid_thermalBaffle1DFvPatchScalarField;
 
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
diff --git a/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/constant/thermoBaffleProperties b/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/constant/thermalBaffleProperties
similarity index 91%
rename from tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/constant/thermoBaffleProperties
rename to tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/constant/thermalBaffleProperties
index acabb40438089d19f6ad5839a27658f47686e44e..9a2dade638e5cab17c6e9b4faf0c0cf5cf9d0dda 100644
--- a/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/constant/thermoBaffleProperties
+++ b/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/constant/thermalBaffleProperties
@@ -11,17 +11,17 @@ FoamFile
     format      ascii;
     class       dictionary;
     location    "constant";
-    object      thermoBaffleProperties;
+    object      thermalBaffleProperties;
 }
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
-thermoBaffleModel  none;
+thermalBaffleModel  none;
 
 active          no;
 
 regionName      none;
 
-thermoBaffleCoeffs
+thermalBaffleCoeffs
 {
 }
 
diff --git a/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/baffleRegion/changeDictionaryDict b/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/baffleRegion/changeDictionaryDict
index 1931c502a6651751c53662583940d9fa2288860a..c325fcd6999b17982c408d26ea7d22c552563ce9 100644
--- a/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/baffleRegion/changeDictionaryDict
+++ b/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/baffleRegion/changeDictionaryDict
@@ -22,7 +22,7 @@ dictionaryReplacement
         {
             "region0_to.*"
             {
-                type                compressible::thermoBaffle;
+                type                compressible::thermalBaffle;
                 neighbourFieldName  T;
                 kappa               solidThermo;
                 kappaName           none;
diff --git a/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/changeDictionaryDict b/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/changeDictionaryDict
index 6146edeb2b4e31f407a9f35aa33175b0b03db2dc..0674354a506bc0e24deb32cc2a01b2de72d4416d 100644
--- a/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/changeDictionaryDict
+++ b/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/changeDictionaryDict
@@ -88,7 +88,7 @@ dictionaryReplacement
         {
             "baffle.*"
             {
-                type        compressible::thermoBaffle1D<hConstSolidThermoPhysics>;
+                type        compressible::thermalBaffle1D<hConstSolidThermoPhysics>;
                 baffleActivated yes;
                 thickness       uniform 0.005;  // thickness [m]
                 Qs              uniform 100;    // heat flux [W/m2]
diff --git a/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/changeDictionaryDict.baffle b/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/changeDictionaryDict.baffle
index d2933855c572bd3905f6492bf15262190aa09d5d..1df570730cc50022f4f6765261c07fe0b6d24ca1 100644
--- a/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/changeDictionaryDict.baffle
+++ b/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/changeDictionaryDict.baffle
@@ -88,7 +88,7 @@ dictionaryReplacement
         {
             "baffle1Wall.*"
             {
-                type   compressible::thermoBaffle1D<hConstSolidThermoPhysics>;
+                type   compressible::thermalBaffle1D<hConstSolidThermoPhysics>;
                 baffleActivated yes;
                 thickness       uniform 0.005;  // thickness [m]
                 Qs              uniform 100;    // heat flux [W/m2]
diff --git a/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/changeDictionaryDict.baffleRegion b/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/changeDictionaryDict.baffleRegion
index 1cbf29f10c6a875fde7c0af7161fc6d80d682be4..dae4c6fe77a8eb7a30b8ba02a66dc87ccf315c6d 100644
--- a/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/changeDictionaryDict.baffleRegion
+++ b/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/changeDictionaryDict.baffleRegion
@@ -91,7 +91,7 @@ dictionaryReplacement
 
             "region0_to.*"
             {
-                type                compressible::thermoBaffle;
+                type                compressible::thermalBaffle;
 
                 // Coupled BC.
                 neighbourFieldName  T;
@@ -99,11 +99,11 @@ dictionaryReplacement
                 kappaName           none;
 
                 // Thermo baffle model
-                thermoBaffleModel   thermoBaffle;
+                thermalBaffleModel   thermalBaffle;
                 regionName          baffleRegion;
                 infoOutput          no;
                 active              yes;
-                thermoBaffleCoeffs
+                thermalBaffleCoeffs
                 {
                 }
 
diff --git a/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/controlDict b/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/controlDict
index acd337d87733d98406a88afc1b08b05124efa50f..f35c15f101f989ea0db7c5697a90cee2b16aaaf5 100644
--- a/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/controlDict
+++ b/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/controlDict
@@ -44,6 +44,6 @@ timePrecision   6;
 
 runTimeModifiable true;
 
-libs ("libthermoBaffleModels.so" "libcompressibleRASModels.so");
+libs ("libthermalBaffleModels.so" "libcompressibleRASModels.so");
 
 // ************************************************************************* //
diff --git a/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/createBafflesDict b/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/createBafflesDict
index bc1ec594fd62af581207933a1c55e8505ab839ff..310a64bd7f8b86f2a11d883411ef40b6b6925e2e 100644
--- a/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/createBafflesDict
+++ b/tutorials/heatTransfer/buoyantSimpleFoam/circuitBoardCooling/system/createBafflesDict
@@ -52,7 +52,7 @@ baffles
                 {
                     T
                     {
-                        type   compressible::thermoBaffle1D<hConstSolidThermoPhysics>;
+                        type   compressible::thermalBaffle1D<hConstSolidThermoPhysics>;
                         baffleActivated yes;
                         thickness       uniform 0.005;  // thickness [m]
                         Qs              uniform 100;    // heat flux [W/m2]
diff --git a/src/regionModels/thermoBaffleModels/derivedFvPatchFields/thermoBaffle/thermoBaffleFvPatchScalarField.H b/src/regionModels/thermalBaffleModels/derivedFvPatchFields/thermalBaffle/thermalBaffleFvPatchScalarField.H
similarity index 85%
rename from src/regionModels/thermoBaffleModels/derivedFvPatchFields/thermoBaffle/thermoBaffleFvPatchScalarField.H
rename to src/regionModels/thermalBaffleModels/derivedFvPatchFields/thermalBaffle/thermalBaffleFvPatchScalarField.H
index a3fa62d442f90db9273606c051a316de2431ac1b..7015f378df6d6c5f1db7cfa0301c7bd5b2cea615 100644
--- a/src/regionModels/thermoBaffleModels/derivedFvPatchFields/thermoBaffle/thermoBaffleFvPatchScalarField.H
+++ b/src/regionModels/thermalBaffleModels/derivedFvPatchFields/thermalBaffle/thermalBaffleFvPatchScalarField.H
@@ -22,7 +22,7 @@ License
     along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.
 
 Class
-    Foam::thermoBaffleFvPatchScalarField
+    Foam::thermalBaffleFvPatchScalarField
 
 Group
     grpThermoBoundaryConditions
@@ -56,11 +56,11 @@ Description
 
 
         // Thermo baffle model
-        thermoBaffleModel   thermoBaffle;
+        thermalBaffleModel   thermalBaffle;
         regionName          baffleRegion;
         infoOutput          yes;
         active              yes;
-        thermoBaffleCoeffs
+        thermalBaffleCoeffs
         {
         }
 
@@ -112,20 +112,20 @@ Description
 
 SeeAlso
     Foam::turbulentTemperatureCoupledBaffleMixedFvPatchScalarField
-    Foam::regionModels::thermoBaffleModels::thermoBaffleModel
+    Foam::regionModels::thermalBaffleModels::thermalBaffleModel
 
 SourceFiles
-    thermoBaffleFvPatchScalarField.C
+    thermalBaffleFvPatchScalarField.C
 
 \*---------------------------------------------------------------------------*/
 
-#ifndef thermoBaffleFvPatchScalarField_H
-#define thermoBaffleFvPatchScalarField_H
+#ifndef thermalBaffleFvPatchScalarField_H
+#define thermalBaffleFvPatchScalarField_H
 
 
 #include "autoPtr.H"
 #include "regionModel.H"
-#include "thermoBaffleModel.H"
+#include "thermalBaffleModel.H"
 #include "turbulentTemperatureCoupledBaffleMixedFvPatchScalarField.H"
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
@@ -137,10 +137,10 @@ namespace compressible
 {
 
 /*---------------------------------------------------------------------------*\
-        Class thermoBaffleFvPatchScalarField Declaration
+        Class thermalBaffleFvPatchScalarField Declaration
 \*---------------------------------------------------------------------------*/
 
-class thermoBaffleFvPatchScalarField
+class thermalBaffleFvPatchScalarField
 :
     public turbulentTemperatureCoupledBaffleMixedFvPatchScalarField
 {
@@ -150,7 +150,7 @@ class thermoBaffleFvPatchScalarField
         bool owner_;
 
         //- Thermal baffle
-        autoPtr<regionModels::thermoBaffleModels::thermoBaffleModel> baffle_;
+        autoPtr<regionModels::thermalBaffleModels::thermalBaffleModel> baffle_;
 
         //- Dictionary
         dictionary dict_;
@@ -159,20 +159,20 @@ class thermoBaffleFvPatchScalarField
 public:
 
     //- Runtime type information
-    TypeName("compressible::thermoBaffle");
+    TypeName("compressible::thermalBaffle");
 
 
     // Constructors
 
         //- Construct from patch and internal field
-        thermoBaffleFvPatchScalarField
+        thermalBaffleFvPatchScalarField
         (
             const fvPatch&,
             const DimensionedField<scalar, volMesh>&
         );
 
         //- Construct from patch, internal field and dictionary
-        thermoBaffleFvPatchScalarField
+        thermalBaffleFvPatchScalarField
         (
             const fvPatch&,
             const DimensionedField<scalar, volMesh>&,
@@ -180,10 +180,10 @@ public:
         );
 
         //- Construct by mapping given
-        //  thermoBaffleFvPatchScalarField onto a new patch
-        thermoBaffleFvPatchScalarField
+        //  thermalBaffleFvPatchScalarField onto a new patch
+        thermalBaffleFvPatchScalarField
         (
-            const thermoBaffleFvPatchScalarField&,
+            const thermalBaffleFvPatchScalarField&,
             const fvPatch&,
             const DimensionedField<scalar, volMesh>&,
             const fvPatchFieldMapper&
@@ -195,14 +195,14 @@ public:
         {
             return tmp<fvPatchScalarField>
             (
-                new thermoBaffleFvPatchScalarField(*this)
+                new thermalBaffleFvPatchScalarField(*this)
             );
         }
 
         //- Construct as copy setting internal field reference
-        thermoBaffleFvPatchScalarField
+        thermalBaffleFvPatchScalarField
         (
-            const thermoBaffleFvPatchScalarField&,
+            const thermalBaffleFvPatchScalarField&,
             const DimensionedField<scalar, volMesh>&
         );
 
@@ -214,7 +214,7 @@ public:
         {
             return tmp<fvPatchScalarField>
             (
-                new thermoBaffleFvPatchScalarField(*this, iF)
+                new thermalBaffleFvPatchScalarField(*this, iF)
             );
         }
 
diff --git a/src/regionModels/thermoBaffleModels/noThermo/noThermo.C b/src/regionModels/thermalBaffleModels/noThermo/noThermo.C
similarity index 93%
rename from src/regionModels/thermoBaffleModels/noThermo/noThermo.C
rename to src/regionModels/thermalBaffleModels/noThermo/noThermo.C
index 1175a0d792a605019bfefd4a612d29020a4c94dc..ea62beed567be5e8f7790e6e02c5a39d6cb26a12 100644
--- a/src/regionModels/thermoBaffleModels/noThermo/noThermo.C
+++ b/src/regionModels/thermalBaffleModels/noThermo/noThermo.C
@@ -33,15 +33,15 @@ namespace Foam
 {
 namespace regionModels
 {
-namespace thermoBaffleModels
+namespace thermalBaffleModels
 {
 
 // * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //
 
 defineTypeNameAndDebug(noThermo, 0);
 
-addToRunTimeSelectionTable(thermoBaffleModel, noThermo, mesh);
-addToRunTimeSelectionTable(thermoBaffleModel, noThermo, dictionary);
+addToRunTimeSelectionTable(thermalBaffleModel, noThermo, mesh);
+addToRunTimeSelectionTable(thermalBaffleModel, noThermo, dictionary);
 
 // * * * * * * * * * * * * Protected Member Functions  * * * * * * * * * * * //
 
@@ -55,7 +55,7 @@ bool noThermo::read()
 
 noThermo::noThermo(const word& modelType, const fvMesh& mesh)
 :
-    thermoBaffleModel(mesh)
+    thermalBaffleModel(mesh)
 {}
 
 
@@ -66,7 +66,7 @@ noThermo::noThermo
     const dictionary& dict
 )
 :
-    thermoBaffleModel(modelType, mesh, dict)
+    thermalBaffleModel(modelType, mesh, dict)
 {}
 
 
@@ -157,7 +157,7 @@ const solidThermo& noThermo::thermo() const
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
-} // End namespace thermoBaffleModels
+} // End namespace thermalBaffleModels
 } // End namespace regionModels
 } // End namespace Foam
 
diff --git a/src/regionModels/thermoBaffleModels/noThermo/noThermo.H b/src/regionModels/thermalBaffleModels/noThermo/noThermo.H
similarity index 96%
rename from src/regionModels/thermoBaffleModels/noThermo/noThermo.H
rename to src/regionModels/thermalBaffleModels/noThermo/noThermo.H
index 8144dad5863076d2b8b29fcc828ee11baab17c1e..cf85fa190105a1b8123fe8fbe6475c01c5c281a3 100644
--- a/src/regionModels/thermoBaffleModels/noThermo/noThermo.H
+++ b/src/regionModels/thermalBaffleModels/noThermo/noThermo.H
@@ -35,7 +35,7 @@ SourceFiles
 #ifndef noThermo_H
 #define noThermo_H
 
-#include "thermoBaffleModel.H"
+#include "thermalBaffleModel.H"
 #include "volFieldsFwd.H"
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
@@ -44,7 +44,7 @@ namespace Foam
 {
 namespace regionModels
 {
-namespace thermoBaffleModels
+namespace thermalBaffleModels
 {
 
 /*---------------------------------------------------------------------------*\
@@ -53,7 +53,7 @@ namespace thermoBaffleModels
 
 class noThermo
 :
-    public thermoBaffleModel
+    public thermalBaffleModel
 {
 private:
 
@@ -139,7 +139,7 @@ public:
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
-} // End namespace thermoBaffleModels
+} // End namespace thermalBaffleModels
 } // End namespace regionModels
 } // End namespace Foam
 
diff --git a/src/regionModels/thermoBaffleModels/thermoBaffle/thermoBaffle.C b/src/regionModels/thermalBaffleModels/thermalBaffle/thermalBaffle.C
similarity index 87%
rename from src/regionModels/thermoBaffleModels/thermoBaffle/thermoBaffle.C
rename to src/regionModels/thermalBaffleModels/thermalBaffle/thermalBaffle.C
index 9044f71fa2090ba757e65ded440ebad24a2f27a4..ed9cbd0021506bce36ed7ec2be6cb4721decf911 100644
--- a/src/regionModels/thermoBaffleModels/thermoBaffle/thermoBaffle.C
+++ b/src/regionModels/thermalBaffleModels/thermalBaffle/thermalBaffle.C
@@ -24,7 +24,7 @@ License
 
 \*---------------------------------------------------------------------------*/
 
-#include "thermoBaffle.H"
+#include "thermalBaffle.H"
 
 #include "fvm.H"
 #include "fvcDiv.H"
@@ -39,37 +39,37 @@ namespace Foam
 {
 namespace regionModels
 {
-namespace thermoBaffleModels
+namespace thermalBaffleModels
 {
 
 // * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //
 
-defineTypeNameAndDebug(thermoBaffle, 0);
+defineTypeNameAndDebug(thermalBaffle, 0);
 
-addToRunTimeSelectionTable(thermoBaffleModel, thermoBaffle, mesh);
-addToRunTimeSelectionTable(thermoBaffleModel, thermoBaffle, dictionary);
+addToRunTimeSelectionTable(thermalBaffleModel, thermalBaffle, mesh);
+addToRunTimeSelectionTable(thermalBaffleModel, thermalBaffle, dictionary);
 
 // * * * * * * * * * * * * Protected Member Functions  * * * * * * * * * * * //
 
-bool thermoBaffle::read()
+bool thermalBaffle::read()
 {
     this->solution().lookup("nNonOrthCorr") >> nNonOrthCorr_;
     return regionModel1D::read();
 }
 
 
-bool thermoBaffle::read(const dictionary& dict)
+bool thermalBaffle::read(const dictionary& dict)
 {
     this->solution().lookup("nNonOrthCorr") >> nNonOrthCorr_;
     return regionModel1D::read(dict);
 }
 
 
-void thermoBaffle::solveEnergy()
+void thermalBaffle::solveEnergy()
 {
     if (debug)
     {
-        Info<< "thermoBaffle::solveEnergy()" << endl;
+        Info<< "thermalBaffle::solveEnergy()" << endl;
     }
 
     const polyBoundaryMesh& rbm = regionMesh().boundaryMesh();
@@ -157,14 +157,14 @@ void thermoBaffle::solveEnergy()
 
 // * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //
 
-thermoBaffle::thermoBaffle
+thermalBaffle::thermalBaffle
 (
     const word& modelType,
     const fvMesh& mesh,
     const dictionary& dict
 )
 :
-    thermoBaffleModel(modelType, mesh, dict),
+    thermalBaffleModel(modelType, mesh, dict),
     nNonOrthCorr_(readLabel(solution().lookup("nNonOrthCorr"))),
     thermo_(solidThermo::New(regionMesh(), dict)),
     h_(thermo_->he()),
@@ -218,13 +218,13 @@ thermoBaffle::thermoBaffle
 }
 
 
-thermoBaffle::thermoBaffle
+thermalBaffle::thermalBaffle
 (
     const word& modelType,
     const fvMesh& mesh
 )
 :
-    thermoBaffleModel(modelType, mesh),
+    thermalBaffleModel(modelType, mesh),
     nNonOrthCorr_(readLabel(solution().lookup("nNonOrthCorr"))),
     thermo_(solidThermo::New(regionMesh())),
     h_(thermo_->he()),
@@ -279,13 +279,13 @@ thermoBaffle::thermoBaffle
 
 // * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //
 
-thermoBaffle::~thermoBaffle()
+thermalBaffle::~thermalBaffle()
 {}
 
 
 // * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * * //
 
-void thermoBaffle::init()
+void thermalBaffle::init()
 {
     if (oneD_ && !constantThickness_)
     {
@@ -294,7 +294,7 @@ void thermoBaffle::init()
 
         if (Qsb!= thickness_.size())
         {
-            FatalErrorIn("thermoBaffle::init()")
+            FatalErrorIn("thermalBaffle::init()")
                 << "the boundary field of Qs is "
                 << Qsb << " and " << nl
                 << "the field 'thickness' is " << thickness_.size() << nl
@@ -304,11 +304,11 @@ void thermoBaffle::init()
 }
 
 
-void thermoBaffle::preEvolveRegion()
+void thermalBaffle::preEvolveRegion()
 {}
 
 
-void thermoBaffle::evolveRegion()
+void thermalBaffle::evolveRegion()
 {
     for (int nonOrth=0; nonOrth<=nNonOrthCorr_; nonOrth++)
     {
@@ -317,43 +317,43 @@ void thermoBaffle::evolveRegion()
 }
 
 
-const tmp<volScalarField> thermoBaffle::Cp() const
+const tmp<volScalarField> thermalBaffle::Cp() const
 {
     return thermo_->Cp();
 }
 
 
-const volScalarField& thermoBaffle::kappaRad() const
+const volScalarField& thermalBaffle::kappaRad() const
 {
     return radiation_->absorptionEmission().a();
 }
 
 
-const volScalarField& thermoBaffle::rho() const
+const volScalarField& thermalBaffle::rho() const
 {
     return thermo_->rho();
 }
 
 
-const volScalarField& thermoBaffle::kappa() const
+const volScalarField& thermalBaffle::kappa() const
 {
     return thermo_->kappa();
 }
 
 
-const volScalarField& thermoBaffle::T() const
+const volScalarField& thermalBaffle::T() const
 {
     return thermo_->T();
 }
 
 
-const solidThermo& thermoBaffle::thermo() const
+const solidThermo& thermalBaffle::thermo() const
 {
     return thermo_;
 }
 
 
-void thermoBaffle::info() const
+void thermalBaffle::info() const
 {
     const labelList& coupledPatches = intCoupledPatchIDs();
 
@@ -375,7 +375,7 @@ void thermoBaffle::info() const
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
-} // end namespace thermoBaffleModels
+} // end namespace thermalBaffleModels
 } // end namespace regionModels
 } // end namespace Foam
 
diff --git a/src/regionModels/thermoBaffleModels/thermoBaffle/thermoBaffle.H b/src/regionModels/thermalBaffleModels/thermalBaffle/thermalBaffle.H
similarity index 88%
rename from src/regionModels/thermoBaffleModels/thermoBaffle/thermoBaffle.H
rename to src/regionModels/thermalBaffleModels/thermalBaffle/thermalBaffle.H
index 93fcf19fd605ec3f8ee822e76f4ce8a99de7eaa7..d706b4864a4cbc7973bc269da20c3b9198bf56a4 100644
--- a/src/regionModels/thermoBaffleModels/thermoBaffle/thermoBaffle.H
+++ b/src/regionModels/thermalBaffleModels/thermalBaffle/thermalBaffle.H
@@ -22,21 +22,21 @@ License
     along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.
 
 Class
-    Foam::thermoBaffle
+    Foam::thermalBaffle
 
 Description
     2D thermal baffle
 
 SourceFiles
-    thermoBaffle.C
-    thermoBaffleI.H
+    thermalBaffle.C
+    thermalBaffleI.H
 
 \*---------------------------------------------------------------------------*/
 
-#ifndef thermoBaffle_H
-#define thermoBaffle_H
+#ifndef thermalBaffle_H
+#define thermalBaffle_H
 
-#include "thermoBaffleModel.H"
+#include "thermalBaffleModel.H"
 #include "volFieldsFwd.H"
 
 
@@ -46,29 +46,29 @@ namespace Foam
 {
 namespace regionModels
 {
-namespace thermoBaffleModels
+namespace thermalBaffleModels
 {
 
 
 /*---------------------------------------------------------------------------*\
-                        Class thermoBaffle Declaration
+                        Class thermalBaffle Declaration
 \*---------------------------------------------------------------------------*/
 
-class thermoBaffle
+class thermalBaffle
 :
-    public thermoBaffleModel
+    public thermalBaffleModel
 {
 private:
 
     // Private member functions
 
         //- Disallow default bitwise copy construct
-        thermoBaffle(const thermoBaffle&);
+        thermalBaffle(const thermalBaffle&);
 
         //- Disallow default bitwise assignment
-        void operator=(const thermoBaffle&);
+        void operator=(const thermalBaffle&);
 
-        //- Initialize thermoBaffle
+        //- Initialize thermalBaffle
         void init();
 
 
@@ -124,16 +124,16 @@ protected:
 public:
 
     //- Runtime type information
-    TypeName("thermoBaffle");
+    TypeName("thermalBaffle");
 
 
     // Constructors
 
         //- Construct from components
-        thermoBaffle(const word& modelType, const fvMesh& mesh);
+        thermalBaffle(const word& modelType, const fvMesh& mesh);
 
         //- Construct from components and dict
-        thermoBaffle
+        thermalBaffle
         (
             const word& modelType,
             const fvMesh& mesh,
@@ -142,7 +142,7 @@ public:
 
 
     //- Destructor
-    virtual ~thermoBaffle();
+    virtual ~thermalBaffle();
 
 
     // Member Functions
@@ -205,13 +205,13 @@ public:
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
-} // End namespace thermoBaffleModels
+} // End namespace thermalBaffleModels
 } // End namespace regionModels
 } // End namespace Foam
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
-#include "thermoBaffleI.H"
+#include "thermalBaffleI.H"
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
diff --git a/src/regionModels/thermoBaffleModels/thermoBaffle/thermoBaffleI.H b/src/regionModels/thermalBaffleModels/thermalBaffle/thermalBaffleI.H
similarity index 90%
rename from src/regionModels/thermoBaffleModels/thermoBaffle/thermoBaffleI.H
rename to src/regionModels/thermalBaffleModels/thermalBaffle/thermalBaffleI.H
index 107274f65e87a0b577bfd81c1c744312afa07b42..c2977f177dc7a541653b49f662e3da7e896c2f44 100644
--- a/src/regionModels/thermoBaffleModels/thermoBaffle/thermoBaffleI.H
+++ b/src/regionModels/thermalBaffleModels/thermalBaffle/thermalBaffleI.H
@@ -24,7 +24,7 @@ License
 
 \*---------------------------------------------------------------------------*/
 
-#include "thermoBaffle.H"
+#include "thermalBaffle.H"
 #include "zeroGradientFvPatchFields.H"
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
@@ -33,12 +33,12 @@ namespace Foam
 {
 namespace regionModels
 {
-namespace thermoBaffleModels
+namespace thermalBaffleModels
 {
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
-inline tmp<scalarField> thermoBaffle::he
+inline tmp<scalarField> thermalBaffle::he
 (
     const scalarField& p,
     const scalarField& T,
@@ -49,7 +49,7 @@ inline tmp<scalarField> thermoBaffle::he
 }
 
 
-inline tmp<volScalarField> thermoBaffle::he() const
+inline tmp<volScalarField> thermalBaffle::he() const
 {
     return thermo_->he();
 }
@@ -57,7 +57,7 @@ inline tmp<volScalarField> thermoBaffle::he() const
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
-} // End namespace thermoBaffleModels
+} // End namespace thermalBaffleModels
 } // End namespace regionModels
 } // End namespace Foam
 
diff --git a/src/regionModels/thermoBaffleModels/thermoBaffleModel/thermoBaffleModel.C b/src/regionModels/thermalBaffleModels/thermalBaffleModel/thermalBaffleModel.C
similarity index 86%
rename from src/regionModels/thermoBaffleModels/thermoBaffleModel/thermoBaffleModel.C
rename to src/regionModels/thermalBaffleModels/thermalBaffleModel/thermalBaffleModel.C
index ff38797a145d4dd9971f1fb12bb4d3c73f1f8ef8..7d8754717c26408f87a7e2967844a168ee3d60a9 100644
--- a/src/regionModels/thermoBaffleModels/thermoBaffleModel/thermoBaffleModel.C
+++ b/src/regionModels/thermalBaffleModels/thermalBaffleModel/thermalBaffleModel.C
@@ -23,7 +23,7 @@ License
 
 \*---------------------------------------------------------------------------*/
 
-#include "thermoBaffleModel.H"
+#include "thermalBaffleModel.H"
 #include "fvMesh.H"
 #include "mappedVariableThicknessWallPolyPatch.H"
 #include "wedgePolyPatch.H"
@@ -34,33 +34,33 @@ namespace Foam
 {
 namespace regionModels
 {
-namespace thermoBaffleModels
+namespace thermalBaffleModels
 {
 
 // * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //
 
-defineTypeNameAndDebug(thermoBaffleModel, 0);
-defineRunTimeSelectionTable(thermoBaffleModel, mesh);
-defineRunTimeSelectionTable(thermoBaffleModel, dictionary);
+defineTypeNameAndDebug(thermalBaffleModel, 0);
+defineRunTimeSelectionTable(thermalBaffleModel, mesh);
+defineRunTimeSelectionTable(thermalBaffleModel, dictionary);
 
 
 // * * * * * * * * * * * * Protected Member Functions  * * * * * * * * * * * //
 
-bool thermoBaffleModel::read()
+bool thermalBaffleModel::read()
 {
     regionModel1D::read();
     return true;
 }
 
 
-bool thermoBaffleModel::read(const dictionary& dict)
+bool thermalBaffleModel::read(const dictionary& dict)
 {
     regionModel1D::read(dict);
     return true;
 }
 
 
-void thermoBaffleModel::init()
+void thermalBaffleModel::init()
 {
     if (active_)
     {
@@ -116,7 +116,7 @@ void thermoBaffleModel::init()
             {
                 FatalErrorIn
                 (
-                    "thermoBaffleModel::thermoBaffleModel"
+                    "thermalBaffleModel::thermalBaffleModel"
                     "("
                     "   const word&,"
                     "   const fvMesh&"
@@ -133,7 +133,7 @@ void thermoBaffleModel::init()
             {
                 FatalErrorIn
                 (
-                    "thermoBaffleModel::thermoBaffleModel"
+                    "thermalBaffleModel::thermalBaffleModel"
                     "("
                     "   const word&,"
                     "   const fvMesh&"
@@ -164,12 +164,12 @@ void thermoBaffleModel::init()
             {
                 FatalErrorIn
                 (
-                    "thermoBaffleModel::thermoBaffleModel"
+                    "thermalBaffleModel::thermalBaffleModel"
                     "("
                     "   const word&,"
                     "   const fvMesh&"
                     ")"
-                )   << " coupled patches in thermoBaffle are " << nl
+                )   << " coupled patches in thermalBaffle are " << nl
                     << " different sizes from list thickness" << nl
                     << exit(FatalError);
             }
@@ -199,7 +199,7 @@ void thermoBaffleModel::init()
 
 // * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //
 
-thermoBaffleModel::thermoBaffleModel(const fvMesh& mesh)
+thermalBaffleModel::thermalBaffleModel(const fvMesh& mesh)
 :
     regionModel1D(mesh),
     thickness_(),
@@ -209,7 +209,7 @@ thermoBaffleModel::thermoBaffleModel(const fvMesh& mesh)
 {}
 
 
-thermoBaffleModel::thermoBaffleModel
+thermalBaffleModel::thermalBaffleModel
 (
     const word& modelType,
     const fvMesh& mesh,
@@ -217,7 +217,7 @@ thermoBaffleModel::thermoBaffleModel
 
 )
 :
-    regionModel1D(mesh, "thermoBaffle", modelType, dict, true),
+    regionModel1D(mesh, "thermalBaffle", modelType, dict, true),
     thickness_(),
     delta_("delta", dimLength, 0.0),
     oneD_(false),
@@ -227,9 +227,13 @@ thermoBaffleModel::thermoBaffleModel
 }
 
 
-thermoBaffleModel::thermoBaffleModel(const word& modelType, const fvMesh& mesh)
+thermalBaffleModel::thermalBaffleModel
+(
+    const word& modelType,
+    const fvMesh& mesh
+)
 :
-    regionModel1D(mesh, "thermoBaffle", modelType),
+    regionModel1D(mesh, "thermalBaffle", modelType),
     thickness_(),
     delta_("delta", dimLength, 0.0),
     oneD_(false),
@@ -241,19 +245,19 @@ thermoBaffleModel::thermoBaffleModel(const word& modelType, const fvMesh& mesh)
 
 // * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //
 
-thermoBaffleModel::~thermoBaffleModel()
+thermalBaffleModel::~thermalBaffleModel()
 {}
 
 
 // * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * * //
 
-void thermoBaffleModel::preEvolveRegion()
+void thermalBaffleModel::preEvolveRegion()
 {}
 
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
-} // End namespace thermoBaffleModels
+} // End namespace thermalBaffleModels
 } // End namespace regionModels
 } // End namespace Foam
 
diff --git a/src/regionModels/thermoBaffleModels/thermoBaffleModel/thermoBaffleModel.H b/src/regionModels/thermalBaffleModels/thermalBaffleModel/thermalBaffleModel.H
similarity index 87%
rename from src/regionModels/thermoBaffleModels/thermoBaffleModel/thermoBaffleModel.H
rename to src/regionModels/thermalBaffleModels/thermalBaffleModel/thermalBaffleModel.H
index d55d6c5ee9c4309c41b81341e3e7562b054d3222..e819a128be6f2241ce3eff0848e7ebd0620de5b8 100644
--- a/src/regionModels/thermoBaffleModels/thermoBaffleModel/thermoBaffleModel.H
+++ b/src/regionModels/thermalBaffleModels/thermalBaffleModel/thermalBaffleModel.H
@@ -22,17 +22,17 @@ License
     along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.
 
 Class
-    Foam::thermoBaffleModel
+    Foam::thermalBaffleModel
 
 Description
 
 SourceFiles
-    thermoBaffleModel.C
+    thermalBaffleModel.C
 
 \*---------------------------------------------------------------------------*/
 
-#ifndef thermoBaffleModel_H
-#define thermoBaffleModel_H
+#ifndef thermalBaffleModel_H
+#define thermalBaffleModel_H
 
 #include "runTimeSelectionTables.H"
 #include "scalarIOField.H"
@@ -49,14 +49,14 @@ namespace Foam
 {
 namespace regionModels
 {
-namespace thermoBaffleModels
+namespace thermalBaffleModels
 {
 
 /*---------------------------------------------------------------------------*\
-                      Class thermoBaffleModel Declaration
+                      Class thermalBaffleModel Declaration
 \*---------------------------------------------------------------------------*/
 
-class thermoBaffleModel
+class thermalBaffleModel
 :
     public regionModel1D
 {
@@ -65,10 +65,10 @@ private:
     // Private Member Functions
 
         //- Disallow default bitwise copy construct
-        thermoBaffleModel(const thermoBaffleModel&);
+        thermalBaffleModel(const thermalBaffleModel&);
 
         //- Disallow default bitwise assignment
-        void operator=(const thermoBaffleModel&);
+        void operator=(const thermalBaffleModel&);
 
         //- Initialize thermal Baffle
         void init();
@@ -103,7 +103,7 @@ protected:
 public:
 
     //- Runtime type information
-    TypeName("thermoBaffleModel");
+    TypeName("thermalBaffleModel");
 
 
     // Declare runtime constructor selection tables
@@ -111,7 +111,7 @@ public:
          declareRunTimeSelectionTable
          (
              autoPtr,
-             thermoBaffleModel,
+             thermalBaffleModel,
              mesh,
              (
                 const word& modelType,
@@ -123,7 +123,7 @@ public:
          declareRunTimeSelectionTable
          (
              autoPtr,
-             thermoBaffleModel,
+             thermalBaffleModel,
              dictionary,
              (
                 const word& modelType,
@@ -137,13 +137,13 @@ public:
     // Constructors
 
         //- Construct null from mesh
-        thermoBaffleModel(const fvMesh& mesh);
+        thermalBaffleModel(const fvMesh& mesh);
 
         //- Construct from type name and mesh
-        thermoBaffleModel(const word& modelType, const fvMesh& mesh);
+        thermalBaffleModel(const word& modelType, const fvMesh& mesh);
 
         //- Construct from type name and mesh and dict
-        thermoBaffleModel
+        thermalBaffleModel
         (
             const word& modelType,
             const fvMesh& mesh,
@@ -154,10 +154,10 @@ public:
     // Selectors
 
         //- Return a reference to the selected model
-        static autoPtr<thermoBaffleModel> New(const fvMesh& mesh);
+        static autoPtr<thermalBaffleModel> New(const fvMesh& mesh);
 
         //- Return a reference to the selected model using dictionary
-        static autoPtr<thermoBaffleModel> New
+        static autoPtr<thermalBaffleModel> New
         (
             const fvMesh& mesh,
             const dictionary& dict
@@ -165,7 +165,7 @@ public:
 
 
     //- Destructor
-    virtual ~thermoBaffleModel();
+    virtual ~thermalBaffleModel();
 
 
     // Member Functions
@@ -227,7 +227,7 @@ public:
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
-} // End namespace thermoBaffleModels
+} // End namespace thermalBaffleModels
 } // End namespace regionModels
 } // End namespace Foam
 
diff --git a/src/regionModels/thermoBaffleModels/thermoBaffleModel/thermoBaffleModelNew.C b/src/regionModels/thermalBaffleModels/thermalBaffleModel/thermalBaffleModelNew.C
similarity index 72%
rename from src/regionModels/thermoBaffleModels/thermoBaffleModel/thermoBaffleModelNew.C
rename to src/regionModels/thermalBaffleModels/thermalBaffleModel/thermalBaffleModelNew.C
index 4261b9f48f7c8da97885b3091e1eb155b2d83ca2..08d4368c27505af91ad96be548acc642ff8cb055 100644
--- a/src/regionModels/thermoBaffleModels/thermoBaffleModel/thermoBaffleModelNew.C
+++ b/src/regionModels/thermalBaffleModels/thermalBaffleModel/thermalBaffleModelNew.C
@@ -23,7 +23,7 @@ License
 
 \*---------------------------------------------------------------------------*/
 
-#include "thermoBaffleModel.H"
+#include "thermalBaffleModel.H"
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
@@ -31,20 +31,20 @@ namespace Foam
 {
 namespace regionModels
 {
-namespace thermoBaffleModels
+namespace thermalBaffleModels
 {
 
 // * * * * * * * * * * * * * * * * Selectors * * * * * * * * * * * * * * * * //
 
-autoPtr<thermoBaffleModel> thermoBaffleModel::New(const fvMesh& mesh)
+autoPtr<thermalBaffleModel> thermalBaffleModel::New(const fvMesh& mesh)
 {
     word modelType;
     {
-        IOdictionary thermoBafflePropertiesDict
+        IOdictionary thermalBafflePropertiesDict
         (
             IOobject
             (
-                "thermoBaffleProperties",
+                "thermalBaffleProperties",
                 mesh.time().constant(),
                 mesh,
                 IOobject::MUST_READ_IF_MODIFIED,
@@ -53,7 +53,7 @@ autoPtr<thermoBaffleModel> thermoBaffleModel::New(const fvMesh& mesh)
             )
         );
 
-        thermoBafflePropertiesDict.lookup("thermoBaffleModel") >> modelType;
+        thermalBafflePropertiesDict.lookup("thermalBaffleModel") >> modelType;
     }
 
     Info<< "Selecting baffle model " << modelType << endl;
@@ -64,25 +64,25 @@ autoPtr<thermoBaffleModel> thermoBaffleModel::New(const fvMesh& mesh)
     if (cstrIter == meshConstructorTablePtr_->end())
     {
 
-        FatalErrorIn("thermoBaffleModel::New(const fvMesh&)")
-            << "Unknown thermoBaffleModel type " << modelType
+        FatalErrorIn("thermalBaffleModel::New(const fvMesh&)")
+            << "Unknown thermalBaffleModel type " << modelType
             << nl << nl
-            <<  "Valid thermoBaffleModel types are:" << nl
+            <<  "Valid thermalBaffleModel types are:" << nl
             << meshConstructorTablePtr_->sortedToc()
             << exit(FatalError);
     }
 
-    return autoPtr<thermoBaffleModel>(cstrIter()(modelType, mesh));
+    return autoPtr<thermalBaffleModel>(cstrIter()(modelType, mesh));
 }
 
 
-autoPtr<thermoBaffleModel> thermoBaffleModel::New
+autoPtr<thermalBaffleModel> thermalBaffleModel::New
 (
     const fvMesh& mesh,
     const dictionary& dict
 )
 {
-    word modelType = dict.lookup("thermoBaffleModel");
+    word modelType = dict.lookup("thermalBaffleModel");
 
     Info<< "Selecting baffle model " << modelType << endl;
 
@@ -92,21 +92,23 @@ autoPtr<thermoBaffleModel> thermoBaffleModel::New
     if (cstrIter == dictionaryConstructorTablePtr_->end())
     {
 
-        FatalErrorIn("thermoBaffleModel::New(const fvMesh&, const dictionary&)")
-            << "Unknown thermoBaffleModel type " << modelType
+        FatalErrorIn
+        (
+            "thermalBaffleModel::New(const fvMesh&, const dictionary&)"
+        )   << "Unknown thermalBaffleModel type " << modelType
             << nl << nl
-            <<  "Valid thermoBaffleModel types are:" << nl
+            <<  "Valid thermalBaffleModel types are:" << nl
             << dictionaryConstructorTablePtr_->sortedToc()
             << exit(FatalError);
     }
 
-    return autoPtr<thermoBaffleModel>(cstrIter()(modelType, mesh, dict));
+    return autoPtr<thermalBaffleModel>(cstrIter()(modelType, mesh, dict));
 }
 
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
-} // End namespace thermoBaffleModels
+} // End namespace thermalBaffleModels
 } // End namespace regionModels
 } // End namespace Foam
 
diff --git a/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermoBaffle1D/thermoBaffle1DFvPatchScalarField.H b/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermalBaffle1D/thermalBaffle1DFvPatchScalarField.H
similarity index 82%
rename from src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermoBaffle1D/thermoBaffle1DFvPatchScalarField.H
rename to src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermalBaffle1D/thermalBaffle1DFvPatchScalarField.H
index 33a26f39fd924a34e90e74b42a2f471419add414..5e6bccf4c9b8172cc1dfdba85574d44d0e02d524 100644
--- a/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermoBaffle1D/thermoBaffle1DFvPatchScalarField.H
+++ b/src/turbulenceModels/compressible/turbulenceModel/derivedFvPatchFields/thermalBaffle1D/thermalBaffle1DFvPatchScalarField.H
@@ -22,19 +22,19 @@ License
     along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.
 
 Class
-    Foam::thermoBaffle1DFvPatchScalarField
+    Foam::thermalBaffle1DFvPatchScalarField
 
 Description
     Boundary which solves the 1D steady state heat transfer equation
     through a baffle.
 
 SourceFiles
-    thermoBaffle1DFvPatchScalarField.C
+    thermalBaffle1DFvPatchScalarField.C
 
 \*---------------------------------------------------------------------------*/
 
-#ifndef thermoBaffle1DFvPatchScalarField_H
-#define thermoBaffle1DFvPatchScalarField_H
+#ifndef thermalBaffle1DFvPatchScalarField_H
+#define thermalBaffle1DFvPatchScalarField_H
 
 #include "mixedFvPatchFields.H"
 #include "autoPtr.H"
@@ -48,11 +48,11 @@ namespace compressible
 {
 
 /*---------------------------------------------------------------------------*\
-            Class thermoBaffle1DFvPatchScalarField Declaration
+            Class thermalBaffle1DFvPatchScalarField Declaration
 \*---------------------------------------------------------------------------*/
 
 template<class solidType>
-class thermoBaffle1DFvPatchScalarField
+class thermalBaffle1DFvPatchScalarField
 :
     public mixedFvPatchScalarField
 {
@@ -77,20 +77,20 @@ class thermoBaffle1DFvPatchScalarField
 public:
 
     //- Runtime type information
-    TypeName("compressible::thermoBaffle1D");
+    TypeName("compressible::thermalBaffle1D");
 
 
     // Constructors
 
         //- Construct from patch and internal field
-        thermoBaffle1DFvPatchScalarField
+        thermalBaffle1DFvPatchScalarField
         (
             const fvPatch&,
             const DimensionedField<scalar, volMesh>&
         );
 
         //- Construct from patch, internal field and dictionary
-        thermoBaffle1DFvPatchScalarField
+        thermalBaffle1DFvPatchScalarField
         (
             const fvPatch&,
             const DimensionedField<scalar, volMesh>&,
@@ -98,19 +98,19 @@ public:
         );
 
         //- Construct by mapping given
-        //  thermoBaffle1DFvPatchScalarField onto a new patch
-        thermoBaffle1DFvPatchScalarField
+        //  thermalBaffle1DFvPatchScalarField onto a new patch
+        thermalBaffle1DFvPatchScalarField
         (
-            const thermoBaffle1DFvPatchScalarField&,
+            const thermalBaffle1DFvPatchScalarField&,
             const fvPatch&,
             const DimensionedField<scalar, volMesh>&,
             const fvPatchFieldMapper&
         );
 
         //- Construct as copy
-        thermoBaffle1DFvPatchScalarField
+        thermalBaffle1DFvPatchScalarField
         (
-            const thermoBaffle1DFvPatchScalarField&
+            const thermalBaffle1DFvPatchScalarField&
         );
 
         //- Construct and return a clone
@@ -118,14 +118,14 @@ public:
         {
             return tmp<fvPatchScalarField>
             (
-                new thermoBaffle1DFvPatchScalarField(*this)
+                new thermalBaffle1DFvPatchScalarField(*this)
             );
         }
 
         //- Construct as copy setting internal field reference
-        thermoBaffle1DFvPatchScalarField
+        thermalBaffle1DFvPatchScalarField
         (
-            const thermoBaffle1DFvPatchScalarField&,
+            const thermalBaffle1DFvPatchScalarField&,
             const DimensionedField<scalar, volMesh>&
         );
 
@@ -137,7 +137,7 @@ public:
         {
             return tmp<fvPatchScalarField>
             (
-                new thermoBaffle1DFvPatchScalarField(*this, iF)
+                new thermalBaffle1DFvPatchScalarField(*this, iF)
             );
         }
 
@@ -176,7 +176,7 @@ public:
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
 #ifdef NoRepository
-#   include "thermoBaffle1DFvPatchScalarField.C"
+#   include "thermalBaffle1DFvPatchScalarField.C"
 #endif
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //